<template>
    <form class="auth" @submit.prevent>
        <div class="auth__switch">
            <div
                class="auth__switch-item"
                :class="[$root.authType == 'login' ? 'auth__switch-item_active' : '']"
                @click="toggle('login')"
            >
                Вход
            </div>
            <div
                class="auth__switch-item"
                :class="[$root.authType == 'reg' ? 'auth__switch-item_active' : '']"
                @click="toggle('reg')"
            >
                Регистрация
            </div>
        </div>
        <div v-if="$root.authType == 'login'">
            <div class="input__field-group">
                <input
                    required="required"
                    placeholder="Введите логин..."
                    type="text"
                    class="input__item"
                    v-model="username"
                />
            </div>
            <div class="input__field-group">
                <input
                    required="required"
                    placeholder="Введите пароль..."
                    type="password"
                    class="input__item"
                    v-model="password"
                />
            </div>
            <div class="input__field-group input__field-group_last">
                <div class="btn-primary input__submit">
                    <button
                        type="submit"
                        class="btn-primary__body"
                        :class="[loginBtn.loading ? 'loading' : '']"
                        @click="login"
                    >
                        ВОЙТИ
                    </button>
                </div>
            </div>
        </div>
        <div v-else>
            <div class="input__field-group">
                <input
                    required="required"
                    placeholder="Придумайте логин..."
                    type="text"
                    class="input__item"
                    v-model="username"
                />
            </div>
            <div class="input__field-group">
                <input
                    required="required"
                    placeholder="Придумайте пароль..."
                    type="password"
                    class="input__item"
                    v-model="password"
                />
            </div>
            <div class="input__field-group">
                <input
                    required="required"
                    placeholder="Повторите пароль..."
                    type="password"
                    class="input__item"
                    v-model="repassword"
                />
            </div>
            <div class="input__field-group">
                <vue-recaptcha
                    v-if="$root.config.recaptcha_site !== null"
                    ref="recaptcha"
                    class="g-recaptcha justify-content-center align-self-center"
                    :sitekey="$root.config.recaptcha_site"
                    @verify="validateCaptcha"
                />
            </div>
            <div class="input__field-group input__field-group_last">
                <div class="btn-primary input__submit">
                    <button
                        type="submit"
                        class="btn-primary__body"
                        :class="[registerBtn.loading ? 'loading' : '']"
                        @click="registration"
                    >
                        РЕГИСТРАЦИЯ
                    </button>
                </div>
            </div>
        </div>
        <div class="auth__divider">
            ИЛИ
        </div>
        <div class="auth__social">
            <a href="/auth/vkontakte" class="auth__social-icon">
                <img width="100%" src="/assets/img/icon/vk.svg" />
            </a>
            <a :href="$root.config.tg_channel" class="auth__social-icon">
                <img width="100%" src="/assets/img/icon/tg.svg" />
            </a>
        </div>
    </form>
</template>

<script>
import { VueRecaptcha } from 'vue-recaptcha'

export default {
    components: { VueRecaptcha },
    data() {
        return {
            loginBtn: {
                loading: false
            },
            registerBtn: {
                loading: false
            },
            username: '',
            password: '',
            repassword: '',
            token: 'token',
        }
    },
    methods: {
        login() {
            this.loginBtn.loading = true;
            this.$root.axios.post('/user/login', {
                username: this.username,
                password: this.password
            })
            .then(response => {
                this.loginBtn.loading = false;
                const {data} = response;

                if(data.error) return notify({
                    theme: 'red',
                    text: data.message
                });

                this.$modal.hideAll();
                this.$root.getUser();
            })
            .catch(err => {
                this.loginBtn.loading = false;
                notify({
                    theme: 'red',
                    text: err.response.statusText
                })
            })
        },
        registration() {
            this.registerBtn.loading = true;
            this.$root.axios.post('/user/registration', {
                username: this.username,
                password: this.password,
                repassword: this.repassword,
                token: this.token
            })
            .then(response => {
                this.registerBtn.loading = false;
                const {data} = response;

                if(data.error) {
                    this.resetCaptcha()
                    return notify({
                        theme: 'red',
                        text: data.message
                    });
                }

                this.$modal.hideAll();
                this.$root.getUser();
            })
            .catch(err => {
                this.registerBtn.loading = false;
                notify({
                    theme: 'red',
                    text: err.response.statusText
                })
            })
        },
        toggle(type) {
            this.$root.authType = type;
        },
        validateCaptcha(token) {
            this.token = token
        },
        resetCaptcha() {
            this.$refs.recaptcha.reset()
            this.token = 'token';
        }
    }
}
</script>

<style scoped>
.g-recaptcha {
    transform: scale(.75);
    justify-content: center;
    display: flex;
}
.auth {
    background: #fff;
    border-radius: 6px;
    padding: 20px 20px 32px;
    z-index: 3;
    overflow: hidden;
    margin-bottom: 1rem;
}
.auth__switch {
    border: 1px solid #eeecfd;
    border-radius: 4px;
    display: flex;
    flex-wrap: wrap;
    justify-content: space-between;
}
.auth__switch-item {
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    flex: 1 0 40%;
    padding: 15px;
    font-weight: 700;
    font-size: 12px;
    line-height: 14px;
    text-align: center;
    color: #a7aecd;
    text-transform: uppercase;
    border-radius: 4px;
    cursor: pointer;
}
.auth__switch-item_active {
    background: #2c80ff;
    color: #fff;
}
.auth__switch-item:first-child {
    max-width: 118px;
}

.auth__error {
    font-size: 12px;
    padding-left: 5px;
    padding-top: 5px;
    color: #ff5757;
    font-weight: 400;
    display: inline-block;
    z-index: 2;
    max-width: 100%;
    overflow: hidden;
}
.auth__error_global {
    width: 100%;
    text-align: center;
    margin-top: 20px;
    padding: 0;
}
.auth__divider {
    font-weight: 700;
    font-size: 12px;
    line-height: 14px;
    text-align: center;
    color: #b4afda;
    margin: 22px 0;
    padding: 0 7px;
    position: relative;
    z-index: 1;
}
.auth__divider:before {
    left: calc(-50% - 20px);
}
.auth__divider:after,
.auth__divider:before {
    content: "";
    position: absolute;
    top: 50%;
    width: 100%;
    height: 1px;
    background: #eeecfd;
    transform: translateY(-50%);
    z-index: -1;
}
.auth__divider:after {
    right: calc(-50% - 20px);
}
.auth__social {
    align-items: center;
}
.auth__social,
.auth__social-icon {
    display: flex;
    justify-content: center;
}
.auth__social-icon {
    width: 35px;
    height: 35px;
    border-radius: 50%;
    background: #2c80ff;
}
.auth__social-icon:hover {
    background: #2873e3;
}
.auth__social-icon img {
    width: 20px;
}
.auth__social-icon:not(:last-child) {
    margin-right: 15px;
}
.block_recaptcha {
    transform-origin: center;
    width: 100%;
}
</style>
